/**
//@HEADER
// ************************************************************************
//
//                   Trios: Trilinos I/O Support
//                 Copyright 2011 Sandia Corporation
//
// Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
// the U.S. Government retains certain rights in this software.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// 3. Neither the name of the Corporation nor the names of the
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY SANDIA CORPORATION "AS IS" AND ANY
// EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SANDIA CORPORATION OR THE
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//Questions? Contact Ron A. Oldfield (raoldfi@sandia.gov)
//
// *************************************************************************
//@HEADER
 */
/**
 * TRIOS does not have any internal threading, but it should run in a
 * multithreaded environment.  The nthread library provides a single API
 * for locks and atomic counters.
 */

#ifndef _TRIOS_THREADS_TYPES_H_
#define _TRIOS_THREADS_TYPES_H_

#include "Trios_config.h"

#include <stdint.h>

#if defined(HAVE_TRIOS_PTHREAD_H)
#include <pthread.h>
#endif

#if defined(HAVE_TRIOS_SEMAPHORE_H)
#include <semaphore.h>
#endif

typedef struct {
    char  *name;
#if defined(HAVE_TRIOS_PTHREAD_MUTEX_T)
    pthread_mutex_t lock;
#elif defined(HAVE_TRIOS_SEM_T)
    sem_t  lock;
    sem_t *lock_ptr;
#else
#warning No locking mechanism available on this system.
#endif
} nthread_lock_t;

typedef struct {
    nthread_lock_t lock;
    int64_t        value;
} nthread_counter_t;

typedef struct {
#if defined(HAVE_TRIOS_PTHREAD_COND_T)
    pthread_cond_t condvar;
#elif defined(HAVE_TRIOS_SEM_T)
/* #warning The semaphores implementation of NSSI threads does not have conditional variables.  Sorry. */
#endif
} nthread_cond_t;


#endif /* _TRIOS_THREADS_TYPES_H_ */
